/*
 *
 * 依赖:
 * zepto.min.js
 * lazyload.js
 * image.js
 * caret.js
 * wrapper.js
 *
 * native 需要实现的接口有:
 * void onClickBody();
 * void onDocumentReady();
 * void onHtmlGenerated(String html);
 * void onTextChanged(int length);
 * String provideContent();
 * String providePlaceholder();
 * int provideContentHeight();
 * int provideContentPaddingTop();
 * int provideContentPaddingBottom();
 * int provideContentPaddingLeft();
 * int provideContentPaddingRight();
 *
 * native 可以调用的方法有:
 * void appendMention(long id, String name);
 * void generateHtml();
 * void requestEditorFocus();
 * void startIntervalSave();
 * void stopIntervalSave();
 * void insertImage(int id, String url);
 * void updateImage(int id, String url, int width, int height);
 * void removeImage(int id);
 * void setPlaceholder(String placeholder);
 * void setContentHeight(int height);
 * void setContentVisible(boolean visible);
 * void setBold();
 * void setItalic();
 * void setUnderline();
 * void setStrikeThrough();
 */

function setBodyFontSize(fontSize) {
 	$('body').css('font-size', fontSize + 'px');
}

function setBold(){
    document.execCommand('bold', false, null);
}

function setItalic(){
    document.execCommand('italic', false, null);
}

function setUnderline(){
    document.execCommand('underline', false, null);
}

function setStrikeThrough(){
    document.execCommand('strikeThrough', false, null);
}

document.getElementsByTagName('input')[0].addEventListener("focus", function() {
	EditorBridge.isFocus(true);
})
document.getElementsByTagName('input')[0].addEventListener("blur", function() {
	EditorBridge.isFocus(false);
})

function getImageCount(){
    var count=$('img').size();
    EditorBridge.getImageCount(count);
}

function isHasUpload(){
    var flag=false;
    $('#editor').find('img').each(function(){
        if($(this).attr("status")==="upload"){
           flag=true;
        }
    })
    return flag;
}


function generateHtml() {
 	var editor = $('#editor').clone();
 	var title = $('#title').clone();
 	removeFailImage();
 	editor.find('img').each(function(){
 	    var path= $(this).attr('remote_path');
 	    if(path!=null&&path!=""&&path!="undefined"){
 	       $(this).attr("src",path);
 	    }
 	    $(this).removeAttr("remote_path");
 	    $(this).removeAttr("onclick");
 	    $(this).removeAttr("status");
 	    $(this).removeAttr("id");

 	}).attr("remote_path")
     var result={
         content:editor.html(),
         title:title.val()
     }

    if(isHasUpload()){
     	EditorBridge.onHtmlGenerated(JSON.stringify(result),true);
    }else{
        EditorBridge.onHtmlGenerated(JSON.stringify(result),false);
    }
 }

 function setHtml(title,content){
    $('#editor').html(content);
    $('#title').val(title);
    $('#title').focus();
    if(content!=''&&content!=null){
        $('#editor').removeClass('medium-editor-placeholder');
    }
    $('#editor').find('img').each(function(){
            var id= Date.parse(new Date())+Math.floor((Math.random()*10)+1)+"i";
            $(this).removeAttr("onclick")
            $(this).attr('id',id);
            $(this).attr("contenteditable",false);
            $(this).bind("click",function(){
            EditorBridge.onclickImage(id);
        })
    })

 }

 function checkBack() {
    $('#editor').find('.img_box').replaceWith("");
    $('img').each(function(){
                var path=$(this).attr("remote_path");
                if(path!=null&&path!=''&&path!="undefined"){
                    $(this).attr("src",path);
                    $(this).removeAttr("remote_path");
                }
            })
 	var editor = $('#editor').clone();
 	var title = $('#title').clone();
     var result={
         content:editor.html(),
         title:title.val()
     }
 	EditorBridge.onCheckBack(JSON.stringify(result));
 }

function getContent() {
     var editor = $('#editor').clone();
      	var title = $('#title').clone();
      	removeFailImage();
      	editor.find('img').each(function(){
      	    var path= $(this).attr('remote_path');
      	    if(path!=null&&path!=""&&path!="undefined"){
      	       $(this).attr("src",path);
      	    }
      	    $(this).removeAttr("remote_path");
      	    $(this).removeAttr("onclick");
      	    $(this).removeAttr("status");
      	    $(this).removeAttr("id");

      	}).attr("remote_path")
          var result={
              content:editor.html(),
              title:title.val()
          }
     EditorBridge.onTextChanged(JSON.stringify(result));
 }

 function setTitle(word){
    var title=$('#title').val();
    if(title==null||title==""||title=="undefined"){
        $('#title').val(word);
    }
 }

function generateTitle() {
	var title = $('#title').clone();
	EditorBridge.onTitleGenerated(title.value());
}

function requestEditorFocus() {
	$('#editor').focus();
}

function removeImage(id){
    $('#'+id).replaceWith("");
}

function autoSave(){
    if(!isHasUpload()){
        var editor = $('#editor').clone();
        var title = $('#title').clone();
        var result={
            content:editor.html(),
            title:title.val()
        }
        if((result.content!=null&&result.content!='')||(result.title!=null&&result.title!='')){
            EditorBridge.autoSave(JSON.stringify(result));
        }
    }
}


// 每隔 10 秒自动保存一次
var intervalId = 0;
function startIntervalSave() {
	stopIntervalSave();
	intervalId = setInterval("autoSave()", 60*1000);
}
function stopIntervalSave() {
	clearInterval(intervalId);
}

function setContentHeight(height) {
	$('#editor').css('min-height', height + 'px');
}

function setContentVisible(visible) {
	if (visible) {
		$('#editor').css('visibility', 'visible');
	} else {
		$('#editor').css('visibility', 'hidden');
	}
}

function getEditorCounts() {
	return $("#editor").text().replace(/\s/g, '').length;
}

function insertImage(id, url) {
	var sel;
	var html = '<br/><div contenteditable="false" onclick="clickImage(\''+id+'\')" id="' + id + '"class="img_box"><img status="upload" onclick="clickImage(\''+id+'\')" src="' + url + '" id="' + id + '"><div class="img_cover"><div class="img_progress">上传中</div></div></div><br/>';
	if (document.queryCommandSupported("insertHTML")) {
		document.execCommand("insertHTML", false, html);
	} else if ((sel = document.selection) && sel.type != 'Control') {
		var range = sel.createRange();
		range.pasteHTML(imgHtml);
		range.collapse(false);
		range.select();
	}
}

function updateImageProgress(id,progress){
    $('#'+id).find('.img_progress').html(progress);
}

function updateImageFail(id){
    $('#'+id).find('.img_progress').html("上传失败");
    $('#'+id).find('img').attr("status","fail")
}

function removeFailImage(){
    $('.img_box').each(function(){
        if($(this).find('img').attr('status')=='fail'){
            $(this).replaceWith('');
        }
    })
}

function updateReplaceImageSucc(id,local,url,width,height){
    var html='<img contenteditable="false" onclick="clickImage(\''+id+'\')" data-height="'+height+'" data-width="'+width+'" id="' + id + '" status="succ" src="'+local+'" remote_path="'+url+'">';
    $('#'+id).replaceWith(html);
}

function insertSay(str){
    var html = '<div class="summary">'+str+'</div>';
    if($('.summary').html()!=null){
        if(str!=null&&str!=""){
           $('.summary').html(str);

        }else{
           $('.summary').remove();
        }
    }else{
        if(str!=null&&str!=""){
           $('#editor').before(html);
           $('.summary').bind('click',function(){
              EditorBridge.editSay();
           })
        }
    }
}


function clickImage(id){
    EditorBridge.onclickImage(id);
}

function mesureText(){

}


// =================================================================================================

var paddingTop = 16;
var paddingBottom = 16;
var paddingLeft = 16;
var paddingRight = 16;

setContentPaddingTop(paddingTop);
setContentPaddingBottom(paddingBottom);
setContentPaddingLeft(paddingLeft);
setContentPaddingRight(paddingRight);

var contentHeight = 500;
contentHeight = contentHeight - paddingTop - paddingBottom;
setContentHeight(contentHeight);
setContentVisible(true);
