/*
 *
 * 依赖:
 * zepto.min.js
 * moment.min.js
 * lazyload.js
 * image.js
 * link-box.js
 * video-box.js
 * share.js
 * wrapper.js
 *
 * native 需要实现的接口有:
 * void onClickBody();
 * void onDocumentReady();
 * int providePaddingTop()
 * int providePaddingBottom()
 * String provideContent();
 * int provideBodyFontSize();
 * int provideTitleFontSize();
 * void onReaderATagClick(String url);
 *
 * native 可以调用的方法有:
 * void setBodyFontSize(int fontSize);
 * void setTitleFontSize(int fontSize);
 * void setContentMinHeight(int minHeight);
 * void setContentOffset(int offset);
 * void setContentVisible(boolean visible);
 * void setupTheme();
 */

function setBodyFontSize(fontSize) {
	$('body').css('font-size', fontSize + 'px');
}

function setTitleFontSize(fontSize) {
	$('div').each(function() {
		var that = $(this);
		if (that.hasClass('title')) {
			that.css('font-size', fontSize + 'px');
		}
	});
}

function setContentMinHeight(minHeight) {
	$('#content').css('min-height', minHeight + 'px');
}

// 一定要保证 window 的高度 >= offset 才会生效
function setContentOffset(offset) {
	window.scrollTo(0, offset);
}

function setContentVisible(visible) {
	if (visible) {
		$('#content').css('visibility', 'visible');
	} else {
		$('#content').css('visibility', 'hidden');
	}
}

function onCharge(){
    ReaderBridge.onCharge();
}

function onChargeRank(){
    ReaderBridge.onChargeRank();
}
// =================================================================================================

function buildContentFromArticle(json) {
	var article = JSON.parse(json);
	var title='';
	if(article.summary!=null&&article.summary!=''){
	    title = buildTitleTag(article.summary);
	}
	var content = article.content != null ? article.content : '';
	return title + content;

}

function buildTitleTag(title) {
	return $('<div />', {'class': 'summary', 'text': title})[0].outerHTML;
}

function buildTime(time) {
	return $('<div />', {'class': 'time', 'text': time})[0].outerHTML;
}


// =================================================================================================
setContentPaddingTop(ReaderBridge.providePaddingTop());
setContentPaddingBottom(ReaderBridge.providePaddingBottom());
setContentPaddingLeft(12);
setContentPaddingRight(12);

var bodyFontSize = ReaderBridge.provideBodyFontSize();
var titleFontSize = ReaderBridge.provideTitleFontSize();
setBodyFontSize(bodyFontSize);
setTitleFontSize(titleFontSize);

var content = ReaderBridge.provideContent();
content = buildContentFromArticle(content);
$('#content').append(content);

setupImage(true);

$(document).ready(function() {
	$('body').click(function(event) {
		var tag = event.target.tagName.toLowerCase();
		if (tag != 'a' && tag != 'img' && tag != 'time') {
			ReaderBridge.onClickBody();
		}
	});

	setContentVisible(true);
	ReaderBridge.onDocumentReady();
});